#!/bin/sh
#
# This file is part of OpenMediaVault.
#
# @license   http://www.gnu.org/licenses/gpl.html GPL Version 3
# @author    Volker Theile <volker.theile@openmediavault.org>
# @copyright Copyright (c) 2009-2011 Volker Theile
#
# OpenMediaVault is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# OpenMediaVault is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OpenMediaVault. If not, see <http://www.gnu.org/licenses/>.

set -e

. /etc/default/openmediavault
. /usr/share/openmediavault/scripts/helper-functions

usage() {
	cat <<EOF
Usage:
  $(basename $0) [options] <enable|disable> <basename>

  basename - The name of the service.

Options:
  -q  Quiet mode, no error messages are generated
  -h  Print a help text
EOF
}

printerror () {
	msg=$*
	basename=$(basename $0)
	if test x${bequiet} = x ; then
		echo ${basename}: "${*}" >&2
	fi
	omv_log "${basename}: ${*}"
}

bequiet=

while getopts 'q?h' option
do
	case ${option} in
	q)
		bequiet=yes
		;;
	h|?)
		usage >&2;
		exit 2
		;;
	esac
done

if test $# -eq 0 ; then
  usage
  exit 2
fi

shift $((OPTIND-1))
action=$1
scriptname=$2

if test ! -f "${OMV_SCRIPTS_DIR}/monit.d/${scriptname}" ; then
	printerror "unknown script, ${OMV_SCRIPTS_DIR}/monit.d/${scriptname} not found."
	exit 100
fi
if test ! -x "${OMV_SCRIPTS_DIR}/monit.d/${scriptname}" ; then
	printerror "script ${OMV_SCRIPTS_DIR}/monit.d/${scriptname} not executable."
	exit 101
fi

case ${action} in
enable)
	${OMV_SCRIPTS_DIR}/monit.d/${scriptname} mkconf 2>&1
	echo "Enabling service ${scriptname}."
	;;
disable)
	${OMV_SCRIPTS_DIR}/monit.d/${scriptname} remove 2>&1
	echo "Service ${scriptname} disabled."
	;;
esac

# Synchronize data on disk, otherwise monit may not realize changes done
# to the /etc/monit/conf.d directory. This will be done to be on the safe
# side.
sync &>/dev/null

# Output help text.
echo "Run 'monit reload' to activate new configuration!"

exit 0
